@@ -1,4 +1,4 @@
 from . import doublespike
 from . import isotope
-from . import plotting
+from . import plot
 from . import regress
\ No newline at end of file
